Use _RPCFile.write properly.
diff --git a/Lib/idlelib/run.py b/Lib/idlelib/run.py
index 831235d..e1e6380 100644
--- a/Lib/idlelib/run.py
+++ b/Lib/idlelib/run.py
@@ -259,8 +259,8 @@
         super.__setattr__(self, 'rpc', rpc)
 
     def __getattribute__(self, name):
-        # When accessing the 'rpc' attribute, use ours
-        if name == 'rpc':
+        # When accessing the 'rpc' attribute, or 'write', use ours
+        if name in ('rpc', 'write'):
             return io.TextIOBase.__getattribute__(self, name)
         # Else only look into the remote object only
         return getattr(self.rpc, name)